@@ -1,4 +1,4 @@
-from .base import BaseConnection
+from db_hammer.base import BaseConnection
 from db_hammer.csv import start as csv_start
 
 try:
@@ -21,7 +21,7 @@ class MySQLConnection(BaseConnection):
             raise Exception("pwd")
         port = kwargs.get("port", 3306)
         charset = kwargs.get("charset", "utf8")
-        super().__init__(port=port, charset=charset, **kwargs)
+        super().__init__(**kwargs)
         self.conn = pymysql.connect(kwargs["host"], kwargs["user"], kwargs["pwd"], kwargs["db_name"], port=port,
                                     charset=charset)
         self.cursor = self.conn.cursor()
@@ -31,7 +31,7 @@ class MySQLConnection(BaseConnection):
 
     def export_data_file(self, sql, dir_path, file_mode="gz", pack_size=500000, bachSize=10000, add_header=True,
                          data_split_chars=',',
-                         data_close_chars='"', encoding="utf-8"):
+                         data_close_chars='"', encoding="utf-8", outingCallback=None):
         """导出数据文件
         @:param sql 导出时的查询SQL
         @:param dir_path 导出的数据文件存放目录
@@ -42,6 +42,7 @@ class MySQLConnection(BaseConnection):
         @:param data_split_chars 每条数据字段分隔字符,csv文件默认为英文逗号
         @:param data_close_chars 每条数据字段关闭字符,csv文件默认为英文双引号
         @:param encoding 文件编码格式，默认为utf-8
+        @:param outingCallback 导出过程中的回调方法
         """
         # 要使用服务器游标，本地游标会内存溢出
         cursor = self.conn.cursor(pymysql.cursors.SSCursor)
@@ -54,5 +55,6 @@ class MySQLConnection(BaseConnection):
                   add_header=add_header,
                   CSV_SPLIT=data_split_chars,
                   CSV_FIELD_CLOSE=data_close_chars,
-                  encoding=encoding)
+                  encoding=encoding,
+                  callback=outingCallback)
         cursor.close()
